@@ -2,7 +2,7 @@
 #' @importFrom dplyr filter select
 #' @importFrom ggplot2 geom_bar coord_flip ylim geom_hline geom_label
 #' @title Cooks' D Bar Plot
-#' @description Bar Plot of Cook's distance to detect observations that strongly influence fitted values of the model.
+#' @description Bar Plot of cook's distance to detect observations that strongly influence fitted values of the model.
 #' @param model an object of class \code{lm}
 #' @details Cook's distance was introduced by American statistician R Dennis Cook in 1977. It is used 
 #' to identify influential data points. It depends on both the residual and leverage i.e it takes it account
@@ -18,6 +18,12 @@
 #' 
 #' A data point having a large cook's d indicates that the data point strongly influences the fitted values.
 #'
+#' @return \code{ols_cooksd_barplot} returns  a list containing the
+#' following components:
+#'
+#' \item{outliers}{a tibble with observation number and \code{cooks distance} that exceed \code{threshold}}
+#' \item{threshold}{\code{threshold} for classifying an observation as an outlier}
+#' 
 #' @examples
 #' model <- lm(mpg ~ disp + hp + wt, data = mtcars)
 #' ols_cooksd_barplot(model)
@@ -40,17 +46,18 @@ ols_cooksd_barplot <- function(model) {
 
 	p <- ggplot(d, aes(x = obs, y = cd, label = txt)) + 
 		geom_bar(width = 0.5, stat = 'identity', aes(fill = Observation)) +
-		scale_fill_manual(values = c('blue', 'red')) + coord_flip() +
+		scale_fill_manual(values = c('blue', 'red')) + 
 		ylim(0, k$maxx) + ylab("Cook's D") + xlab('Observation') + 
 		ggtitle("Cook's D Bar Plot") + geom_hline(yintercept = 0) +
 		geom_hline(yintercept = k$ts, colour = 'red') +
 		geom_text(hjust = -0.2, nudge_x = 0.05, size = 2) +
 		annotate("text", x = Inf, y = Inf, hjust = 1.2, vjust = 2, 
                   family="serif", fontface="italic", colour="darkred", 
-                  label = paste('Threshold:', k$ts))
+                  label = paste('Threshold:', round(k$ts, 3)))
 	
 	suppressWarnings(print(p))
 	colnames(f) <- c("Observation", "Cook's Distance")
-	invisible(f)
+	result <- list(outliers = f, threshold = round(k$ts, 3))
+	invisible(result)
 
 }
\ No newline at end of file
